pub struct Bf16Add;Expand description
bfloat16 addition as an operation type.
The operation is a type rather than a closure, so tenferro’s kernels are instantiated once per element type and operation instead of once per call site.
Examples
use tenferro_bf16_proof::{Bf16, Bf16Add};
use tenferro_cpu::BinaryScalarOp;
let sum = <Bf16Add as BinaryScalarOp<Bf16>>::apply(Bf16::from_f32(1.0), Bf16::from_f32(2.0));
assert_eq!(sum.to_f32(), 3.0);Trait Implementations